@@ -18,7 +18,7 @@ impl<T> Triangle<T> {
 
 impl<T> Triangle<T>
 where
-    T: Clone + Num,
+    T: Clone + Real,
 {
     pub fn is_valid(&self) -> bool {
         let (ab, ac, _) = self.edges();
@@ -33,6 +33,7 @@ where
     pub fn perimeter(&self) -> T {
         todo!()
     }
+
     /// Returns the area of the triangle.
     pub fn area(&self) -> T {
         // Det[{{x0, y0, 1}, {x1, y1, 1}, {x2, y2, 1}}] / 2
@@ -44,6 +45,14 @@ where
         let det3 = self.vertex[2].x.clone() * self.vertex[0].y.clone() - self.vertex[0].x.clone() * self.vertex[2].y.clone();
         (det1 + det2 + det3) / two()
     }
+    /// Get the inscribed circle of the triangle
+    pub fn inscribed_circle(&self) -> Circle<T> {
+        todo!()
+    }
+    /// Get the circumscribed circle of the triangle.
+    pub fn circumscribed_circle(&self) -> Circle<T> {
+        Circle::from_3_points(self.vertex[0].clone(), self.vertex[1].clone(), self.vertex[2].clone())
+    }
     #[inline]
     fn edges(&self) -> (Vector<T>, Vector<T>, Vector<T>) {
         todo!()
